### Name: sp.predict
### Title: Prediction for new points given a ggt.sp object
### Aliases: sp.predict
### Keywords: misc

### ** Examples

## Not run: 
##D library(MBA)
##D 
##D data(FBC07)
##D 
##D ##Divide the data into model and prediction sets
##D Y.1 <- FBC07[1:100,"Y.1"]
##D Y.2 <- FBC07[1:100,"Y.2"]
##D model.coords <- as.matrix(FBC07[1:100,c("coord.X", "coord.Y")])
##D pred.coords <- as.matrix(FBC07[151:200,c("coord.X", "coord.Y")])
##D 
##D #############################
##D ##   Univariate model
##D #############################
##D 
##D ##Fit some model with ggt.sp.
##D K.prior <- prior(dist="IG", shape=2, scale=5)
##D Psi.prior <- prior(dist="IG", shape=2, scale=5)
##D phi.prior <- prior(dist="UNIF", a=0.06, b=3)
##D 
##D var.update.control <-
##D   list("K"=list(starting=5, tuning=0.5, prior=K.prior),
##D        "Psi"=list(starting=5, tuning=0.5, prior=Psi.prior),
##D        "phi"=list(starting=0.1, tuning=0.5, prior=phi.prior)
##D        )
##D 
##D beta.control <- list(update="GIBBS", prior=prior(dist="FLAT"))
##D 
##D run.control <- list("n.samples"=1000)
##D 
##D Fit <- ggt.sp(formula=Y.2~1, run.control=run.control,
##D               coords=model.coords,
##D               var.update.control=var.update.control,
##D               beta.update.control=beta.control,
##D               cov.model="exponential")
##D 
##D ##Now make predictions for the holdout set.
##D ##Step 1. make the design matrix for the prediction points.
##D pred.covars <- as.matrix(rep(1, nrow(pred.coords)))
##D 
##D ##Step 2. call sp.predict.
##D Pred <- sp.predict(Fit, pred.covars=pred.covars,
##D                    pred.coords=pred.coords)
##D 
##D ##Step 3. check out the predicted random effects and
##D ##predicted response variable.
##D Pred.sp.effects.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred$pred.sp.effects)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D Pred.Y.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred$pred.y)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D par(mfrow=c(1,2))
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted random spatial effects")
##D contour(Pred.sp.effects.surf, add=TRUE)
##D 
##D image(Pred.Y.surf, xaxs="r", yaxs="r",
##D       main="Predicted Y.2")
##D contour(Pred.Y.surf, add=TRUE)
##D 
##D #############################
##D ##   Multivariate models
##D #############################
##D 
##D ##Fit some model with ggt.sp.
##D K.prior <- prior(dist="IWISH", df=2, S=diag(c(3, 6)))
##D Psi.prior <- prior(dist="IWISH", df=2, S=diag(c(7, 5)))
##D phi.prior <- prior(dist="UNIF", a=0.06, b=3)
##D 
##D K.starting <- matrix(c(2,-3, 0, 1), 2, 2)
##D Psi.starting <- diag(c(3, 2))
##D 
##D var.update.control <-
##D   list("K"=list(starting=K.starting, tuning=diag(c(0.1, 0.5, 0.1)),
##D          prior=K.prior),
##D        "Psi"=list(starting=Psi.starting, tuning=diag(c(0.1, 0.5, 0.1)),
##D          prior=Psi.prior),
##D        "phi"=list(starting=0.1, tuning=0.5,
##D          prior=list(phi.prior, phi.prior))
##D        )
##D 
##D beta.control <- list(update="GIBBS", prior=prior(dist="FLAT"))
##D 
##D run.control <- list("n.samples"=1000, "sp.effects"=FALSE)
##D 
##D Fit.mv <-
##D   ggt.sp(formula=list(Y.1~1, Y.2~1), run.control=run.control,
##D          coords=model.coords,
##D          var.update.control=var.update.control,
##D          beta.update.control=beta.control,
##D          cov.model="exponential")
##D 
##D ##Now make predictions for the holdout set.
##D ##Step 1. make the design matrix for the prediction points using
##D ##the mk.mv.X function.
##D pred.covars.1 <- as.matrix(rep(1, nrow(pred.coords)))
##D pred.covars.2 <- as.matrix(rep(1, nrow(pred.coords)))
##D 
##D pred.covars.mv <- mk.mv.X(list(pred.covars.1, pred.covars.2))
##D 
##D ##Step 2. call sp.predict.
##D Pred.mv <- sp.predict(Fit.mv, pred.covars=pred.covars.mv,
##D                       pred.coords=pred.coords)
##D 
##D ##Step 3. check out the predicted random effects and
##D ##predicted response variables.   Recall, these are
##D ##organized as m consecutive rows for each point.
##D Pred.sp.effects.1 <-
##D   Pred.mv$pred.sp.effects[seq(1, nrow(Pred.mv$pred.sp.effects), 2),]
##D 
##D Pred.sp.effects.2 <-
##D   Pred.mv$pred.sp.effects[seq(2, nrow(Pred.mv$pred.sp.effects), 2),]
##D 
##D Pred.Y.1 <-
##D   Pred.mv$pred.sp.effects[seq(1, nrow(Pred.mv$pred.y), 2),]
##D 
##D Pred.Y.2 <-
##D   Pred.mv$pred.sp.effects[seq(2, nrow(Pred.mv$pred.y), 2),]
##D 
##D ##Then map.
##D Pred.sp.effects.1.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred.sp.effects.1)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D Pred.sp.effects.2.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred.sp.effects.2)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D Pred.Y.1.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred.Y.1)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D Pred.Y.2.surf <-
##D   mba.surf(cbind(pred.coords, rowMeans(Pred.Y.2)),
##D            no.X=100, no.Y=100, extend=TRUE)$xyz.est
##D 
##D par(mfrow=c(2,2))
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted random spatial effects Y.1")
##D contour(Pred.sp.effects.1.surf, add=TRUE)
##D 
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted random spatial effects Y.2")
##D contour(Pred.sp.effects.2.surf, add=TRUE)
##D 
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted Y.1")
##D contour(Pred.Y.1.surf, add=TRUE)
##D 
##D image(Pred.sp.effects.surf, xaxs="r", yaxs="r",
##D       main="Predicted Y.2")
##D contour(Pred.Y.2.surf, add=TRUE)
## End(Not run)



